@@ -242,6 +242,15 @@ fn bytes<'a>(input: &'a str)
         .parse(input)
 }
 
+/// Parse a noop statement
+fn noop<'a>(input: &'a str)
+-> ParseRes<Statement> {
+    context("noop statement",
+        s_expr(tag("noop"))
+            .map(|_| Statement::Noop))
+        .parse(input)
+}
+
 /// Parse a [U256] integer.
 fn int<'a>(input: &'a str)
 -> ParseRes<U256> {
@@ -257,10 +266,10 @@ fn int<'a>(input: &'a str)
 fn vector<'a>(input: &'a str)
 -> ParseRes<Vec<Expr>> {
     context("vector",
-        delimited(
-            tag("#(").and(multispace0),
-            cut(separated_list0(many1(ws_or_comment), expr)),
-            multispace0.and(char(')'))))
+        s_expr(
+            tag("vector").and(multispace0)
+            .and(cut(separated_list0(many1(ws_or_comment), expr))))
+        .map(|(_,es)| es))
         (input)
 }
 
@@ -331,6 +340,14 @@ pub fn if_expr<'a>(input: &'a str)
         .parse(input)
 }
 
+pub fn if_stmnt<'a>(input: &'a str)
+-> ParseRes<(Expr, Statement, Statement)> {
+    context("if expression",
+        list!(tag("set-if"), cut(expr), cut(statement), cut(statement)))
+        .map(|(_,e1,s2,s3)| (e1,s2,s3))
+        .parse(input)
+}
+
 pub fn sigeok<'a>(input: &'a str)
 -> ParseRes<(u16, Expr, Expr, Expr)> {
     context("sigeok operation",
@@ -384,7 +401,9 @@ pub fn statement<'a>(input: &'a str)
     alt((
          setlet_bind.map(|(binds, stmnts)| Statement::SetLet(binds, stmnts)),
          set,
+         noop,
          loop_stmnt.map(|(n,s)| Statement::Loop(n, Box::new(s))),
+         if_stmnt.map(|(p,t,f)| Statement::If(Box::new(p), Box::new(t), Box::new(f))),
      )).parse(input)
 }
 
